# Schemasheets - make datamodels using spreadsheets

<p align="center">
    <a href="https://github.com/linkml/schemasheets/actions/workflows/main.yml">
        <img alt="Tests" src="https://github.com/linkml/schemasheets/actions/workflows/main.yml/badge.svg" />
    </a>
    <a href="https://pypi.org/project/linkml">
        <img alt="PyPI" src="https://img.shields.io/pypi/v/linkml" />
    </a>
    <a href="https://pypi.org/project/sssom">
        <img alt="PyPI - Python Version" src="https://img.shields.io/pypi/pyversions/sssom" />
    </a>
    <a href="https://github.com/linkml/schemasheets/blob/main/LICENSE">
        <img alt="PyPI - License" src="https://img.shields.io/pypi/l/sssom" />
    </a>
    <a href="https://github.com/psf/black">
        <img src="https://img.shields.io/badge/code%20style-black-000000.svg" alt="Code style: black">
    </a>
</p>

Schemasheets is a framework for managing your schema using
spreadsheets (Google Sheets, Excel). It works by compiling down to
[LinkML](https://linkml.io), which can itself be compuled to a variety
of formalisms.

For more info, see the [documentation](https://linkml.io/schemasheets)
